@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_COMPAT_STDIO_H
-#define _SQUID_COMPAT_STDIO_H
+#ifndef SQUID_COMPAT_STDIO_H
+#define SQUID_COMPAT_STDIO_H
 
 /** 64-bit broken <cstdio>
  *
@@ -62,5 +62,5 @@ inline FILE * tmpfile(void) { return tmpfile64(); }
 #define MAXPATHLEN SQUID_MAXPATHLEN
 #endif
 
-#endif /* _SQUID_COMPAT_STDIO_H */
+#endif /* SQUID_COMPAT_STDIO_H */
 
