@@ -6,10 +6,10 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_DEBUG_H
-#define SQUID_SNMP_DEBUG_H
+#ifndef SQUID_INCLUDE_SNMP_DEBUG_H
+#define SQUID_INCLUDE_SNMP_DEBUG_H
 
 SQUIDCEXTERN void snmplib_debug(int, const char *,...) PRINTF_FORMAT_ARG2;
 
-#endif /* SQUID_SNMP_DEBUG_H */
+#endif /* SQUID_INCLUDE_SNMP_DEBUG_H */
 
