@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_PDU_H
-#define SQUID_SNMP_PDU_H
+#ifndef SQUID_INCLUDE_SNMP_PDU_H
+#define SQUID_INCLUDE_SNMP_PDU_H
 
 /* required for oid typedef */
 #include "asn1.h"
@@ -103,5 +103,5 @@ void snmp_add_null_var(struct snmp_pdu *, oid *, int);
 }
 #endif
 
-#endif /* SQUID_SNMP_PDU_H */
+#endif /* SQUID_INCLUDE_SNMP_PDU_H */
 
