@@ -98,7 +98,6 @@ static char *rn_zeros, *rn_ones;
 #define rm_leaf rm_rmu.rmu_leaf /* extra field would make 32 bytes */
 
 /* Helper macros */
-#define squid_Bcmp(a, b, l) (l == 0 ? 0 : memcmp((caddr_t)(a), (caddr_t)(b), (u_long)l))
 #define squid_R_Malloc(p, t, n) (p = (t) xmalloc((unsigned int)(n)))
 #define squid_Free(p) xfree((char *)p)
 #define squid_MKGet(m) {\
@@ -143,7 +142,7 @@ static char *rn_zeros, *rn_ones;
  * node as high in the tree as we can go.
  *
  * The present version of the code makes use of normal routes in short-
- * circuiting an explict mask and compare operation when testing whether
+ * circuiting an explicit mask and compare operation when testing whether
  * a key satisfies a normal route, and also in remembering the unique leaf
  * that governs a subtree.
  */
@@ -151,7 +150,7 @@ static char *rn_zeros, *rn_ones;
 struct squid_radix_node *
 squid_rn_search(void *v_arg, struct squid_radix_node *head) {
     register struct squid_radix_node *x;
-    register caddr_t v;
+    register char *v;
 
     for (x = head, v = v_arg; x->rn_b >= 0;) {
         if (x->rn_bmask & v[x->rn_off])
@@ -165,7 +164,7 @@ squid_rn_search(void *v_arg, struct squid_radix_node *head) {
 struct squid_radix_node *
 squid_rn_search_m(void *v_arg, struct squid_radix_node *head, void *m_arg) {
     register struct squid_radix_node *x;
-    register caddr_t v = v_arg, m = m_arg;
+    register char *v = v_arg, *m = m_arg;
 
     for (x = head; x->rn_b >= 0;) {
         if ((x->rn_bmask & m[x->rn_off]) &&
@@ -180,8 +179,8 @@ squid_rn_search_m(void *v_arg, struct squid_radix_node *head, void *m_arg) {
 int
 squid_rn_refines(void *m_arg, void *n_arg)
 {
-    register caddr_t m = m_arg, n = n_arg;
-    register caddr_t lim, lim2 = lim = n + *(u_char *) n;
+    register char *m = m_arg, *n = n_arg;
+    register char *lim, *lim2 = lim = n + *(u_char *) n;
     int longer = (*(u_char *) n++) - (int) (*(u_char *) m++);
     int masks_are_equal = 1;
 
@@ -206,7 +205,7 @@ squid_rn_refines(void *m_arg, void *n_arg)
 struct squid_radix_node *
 squid_rn_lookup(void *v_arg, void *m_arg, struct squid_radix_node_head *head) {
     register struct squid_radix_node *x;
-    caddr_t netmask = 0;
+    char *netmask = NULL;
 
     if (m_arg) {
         if ((x = squid_rn_addmask(m_arg, 1, head->rnh_treetop->rn_off)) == 0)
@@ -243,10 +242,10 @@ rn_satsifies_leaf(char *trial, register struct squid_radix_node *leaf, int skip)
 
 struct squid_radix_node *
 squid_rn_match(void *v_arg, struct squid_radix_node_head *head) {
-    caddr_t v = v_arg;
+    char *v = v_arg;
     register struct squid_radix_node *t = head->rnh_treetop, *x;
-    register caddr_t cp = v, cp2;
-    caddr_t cplim;
+    register char *cp = v, *cp2;
+    char *cplim;
     struct squid_radix_node *saved_t, *top = t;
     int off = t->rn_off, vlen = *(u_char *) cp, matched_off;
     register int test, b, rn_b;
@@ -340,13 +339,6 @@ on1:
     return 0;
 }
 
-#ifdef RN_DEBUG
-int rn_nodenum;
-struct squid_radix_node *rn_clist;
-int rn_saveinfo;
-int rn_debug = 1;
-#endif
-
 struct squid_radix_node *
 squid_rn_newpair(void *v, int b, struct squid_radix_node nodes[2]) {
     register struct squid_radix_node *tt = nodes, *t = tt + 1;
@@ -355,35 +347,28 @@ squid_rn_newpair(void *v, int b, struct squid_radix_node nodes[2]) {
     t->rn_l = tt;
     t->rn_off = b >> 3;
     tt->rn_b = -1;
-    tt->rn_key = (caddr_t) v;
+    tt->rn_key = (char *) v;
     tt->rn_p = t;
     tt->rn_flags = t->rn_flags = RNF_ACTIVE;
-#ifdef RN_DEBUG
-    tt->rn_info = rn_nodenum++;
-    t->rn_info = rn_nodenum++;
-    tt->rn_twin = t;
-    tt->rn_ybro = rn_clist;
-    rn_clist = tt;
-#endif
     return t;
 }
 
 struct squid_radix_node *
 squid_rn_insert(void *v_arg, struct squid_radix_node_head *head, int *dupentry, struct squid_radix_node nodes[2]) {
-    caddr_t v = v_arg;
+    char *v = v_arg;
     struct squid_radix_node *top = head->rnh_treetop;
     int head_off = top->rn_off, vlen = (int) *((u_char *) v);
     register struct squid_radix_node *t = squid_rn_search(v_arg, top);
-    register caddr_t cp = v + head_off;
+    register char *cp = v + head_off;
     register int b;
     struct squid_radix_node *tt;
     /*
      * Find first bit at which v and t->rn_key differ
      */
     {
-        register caddr_t cp2 = t->rn_key + head_off;
+        register char *cp2 = t->rn_key + head_off;
         register int cmp_res;
-        caddr_t cplim = v + vlen;
+        char *cplim = v + vlen;
 
         while (cp < cplim)
             if (*cp2++ != *cp++)
@@ -406,11 +391,6 @@ on1:
             else
                 x = x->rn_l;
         } while (b > (unsigned) x->rn_b);   /* x->rn_b < b && x->rn_b >= 0 */
-#ifdef RN_DEBUG
-        if (rn_debug)
-            fprintf(stderr, "squid_rn_insert: Going In:\n");
-        traverse(p);
-#endif
         t = squid_rn_newpair(v_arg, b, nodes);
         tt = t->rn_l;
         if ((cp[p->rn_off] & p->rn_bmask) == 0)
@@ -425,19 +405,15 @@ on1:
             t->rn_r = tt;
             t->rn_l = x;
         }
-#ifdef RN_DEBUG
-        if (rn_debug)
-            log(LOG_DEBUG, "squid_rn_insert: Coming Out:\n"), traverse(p);
-#endif
     }
     return (tt);
 }
 
 struct squid_radix_node *
 squid_rn_addmask(void *n_arg, int search, int skip) {
-    caddr_t netmask = (caddr_t) n_arg;
+    char *netmask = (char *) n_arg;
     register struct squid_radix_node *x;
-    register caddr_t cp, cplim;
+    register char *cp, *cplim;
     register int b = 0, mlen, j;
     int maskduplicated, m0, isnormal;
     struct squid_radix_node *saved_x;
@@ -476,7 +452,7 @@ squid_rn_addmask(void *n_arg, int search, int skip) {
     if ((saved_x = x) == 0)
         return (0);
     memset(x, '\0', squid_max_keylen + 2 * sizeof(*x));
-    netmask = cp = (caddr_t) (x + 2);
+    netmask = cp = (char *) (x + 2);
     memcpy(cp, addmask_key, mlen);
     x = squid_rn_insert(cp, squid_mask_rnhead, &maskduplicated, x);
     if (maskduplicated) {
@@ -541,12 +517,12 @@ rn_new_radix_mask(struct squid_radix_node *tt, struct squid_radix_mask *next) {
 
 struct squid_radix_node *
 squid_rn_addroute(void *v_arg, void *n_arg, struct squid_radix_node_head *head, struct squid_radix_node treenodes[2]) {
-    caddr_t v = (caddr_t) v_arg, netmask = (caddr_t) n_arg;
+    char *v = (char *) v_arg, *netmask = (char *) n_arg;
     register struct squid_radix_node *t, *x = NULL, *tt;
     struct squid_radix_node *saved_tt, *top = head->rnh_treetop;
     short b = 0, b_leaf = 0;
     int keyduplicated;
-    caddr_t mmask;
+    char *mmask;
     struct squid_radix_mask *m, **mp;
 
     /*
@@ -606,15 +582,7 @@ squid_rn_addroute(void *v_arg, void *n_arg, struct squid_radix_node_head *head,
             tt->rn_dupedkey = t->rn_dupedkey;
             t->rn_dupedkey = tt;
         }
-#ifdef RN_DEBUG
-        t = tt + 1;
-        tt->rn_info = rn_nodenum++;
-        t->rn_info = rn_nodenum++;
-        tt->rn_twin = t;
-        tt->rn_ybro = rn_clist;
-        rn_clist = tt;
-#endif
-        tt->rn_key = (caddr_t) v;
+        tt->rn_key = (char *) v;
         tt->rn_b = -1;
         tt->rn_flags = RNF_ACTIVE;
     }
@@ -697,7 +665,7 @@ squid_rn_delete(void *v_arg, void *netmask_arg, struct squid_radix_node_head *he
     register struct squid_radix_node *t, *p, *x, *tt;
     struct squid_radix_mask *m, *saved_m, **mp;
     struct squid_radix_node *dupedkey, *saved_tt, *top;
-    caddr_t v, netmask;
+    char *v, *netmask;
     int b, head_off, vlen;
 
     v = v_arg;
@@ -762,13 +730,6 @@ on1:
      */
     if (tt->rn_flags & RNF_ROOT)
         return (0);
-#ifdef RN_DEBUG
-    /* Get us out of the creation list */
-    for (t = rn_clist; t && t->rn_ybro != tt; t = t->rn_ybro) {
-    }
-    if (t)
-        t->rn_ybro = tt->rn_ybro;
-#endif
     t = tt->rn_p;
     if ((dupedkey = saved_tt->rn_dupedkey)) {
         if (tt == saved_tt) {
@@ -788,15 +749,8 @@ on1:
         }
         t = tt + 1;
         if (t->rn_flags & RNF_ACTIVE) {
-#ifndef RN_DEBUG
             *++x = *t;
             p = t->rn_p;
-#else
-            b = t->rn_info;
-            *++x = *t;
-            t->rn_info = b;
-            p = t->rn_p;
-#endif
             if (p->rn_l == t)
                 p->rn_l = x;
             else
@@ -836,13 +790,7 @@ on1:
                         squid_MKFree(m);
                     m = mm;
                 }
-#if RN_DEBUG
-            if (m)
-                fprintf(stderr, "%s %x at %x\n",
-                        "squid_rn_delete: Orphaned Mask", (int) m, (int) x);
-#else
             assert(m == NULL);
-#endif
         }
     }
     /*
@@ -850,13 +798,7 @@ on1:
      */
     x = tt + 1;
     if (t != x) {
-#ifndef RN_DEBUG
         *t = *x;
-#else
-        b = t->rn_info;
-        *t = *x;
-        t->rn_info = b;
-#endif
         t->rn_l->rn_p = t;
         t->rn_r->rn_p = t;
         p = x->rn_p;
