@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_COLLAPSING_HISTORY_H
-#define SQUID_COLLAPSING_HISTORY_H
+#ifndef SQUID_SRC_COLLAPSINGHISTORY_H
+#define SQUID_SRC_COLLAPSINGHISTORY_H
 
 /// collapsed forwarding history of a master transaction
 class CollapsingHistory
@@ -24,5 +24,5 @@ public:
     int otherCollapses = 0;
 };
 
-#endif /* SQUID_COLLAPSING_HISTORY_H */
+#endif /* SQUID_SRC_COLLAPSINGHISTORY_H */
 
