@@ -45,7 +45,7 @@ strListAdd(String &str, const SBuf &item, char delimiter)
 int
 strListIsMember(const String * list, const SBuf &m, char del)
 {
-    const char *pos = NULL;
+    const char *pos = nullptr;
     const char *item;
     int ilen = 0;
 
@@ -69,7 +69,7 @@ strListIsSubstr(const String * list, const char *s, char del)
      * Note: the original code with a loop is broken because it uses strstr()
      * instead of strnstr(). If 's' contains a 'del', strListIsSubstr() may
      * return true when it should not. If 's' does not contain a 'del', the
-     * implementaion is equavalent to strstr()! Thus, we replace the loop with
+     * implementation is equavalent to strstr()! Thus, we replace the loop with
      * strstr() above until strnstr() is available.
      */
 }
