@@ -11,8 +11,7 @@
 #include "squid.h"
 #include "acl/Checklist.h"
 #include "acl/Tree.h"
-#include "Debug.h"
-#include "profiler/Profiler.h"
+#include "debug/Stream.h"
 
 #include <algorithm>
 
@@ -60,21 +59,21 @@ ACLChecklist::markFinished(const Acl::Answer &finalAnswer, const char *reason)
     assert (!finished() && !asyncInProgress());
     finished_ = true;
     answer_ = finalAnswer;
-    debugs(28, 3, HERE << this << " answer " << answer_ << " for " << reason);
+    debugs(28, 3, this << " answer " << answer_ << " for " << reason);
 }
 
 /// Called first (and once) by all checks to initialize their state
 void
 ACLChecklist::preCheck(const char *what)
 {
-    debugs(28, 3, HERE << this << " checking " << what);
+    debugs(28, 3, this << " checking " << what);
 
     // concurrent checks using the same Checklist are not supported
     assert(!occupied_);
     occupied_ = true;
     asyncLoopDepth_ = 0;
 
-    AclMatchedName = NULL;
+    AclMatchedName = nullptr;
     finished_ = false;
 }
 
@@ -163,7 +162,7 @@ ACLChecklist::checkCallback(Acl::Answer answer)
     debugs(28, 3, "ACLChecklist::checkCallback: " << this << " answer=" << answer);
 
     callback_ = callback;
-    callback = NULL;
+    callback = nullptr;
 
     if (cbdataReferenceValidDone(callback_data, &cbdata_))
         callback_(answer, cbdata_);
@@ -175,9 +174,9 @@ ACLChecklist::checkCallback(Acl::Answer answer)
 }
 
 ACLChecklist::ACLChecklist() :
-    accessList (NULL),
-    callback (NULL),
-    callback_data (NULL),
+    accessList (nullptr),
+    callback (nullptr),
+    callback_data (nullptr),
     asyncCaller_(false),
     occupied_(false),
     finished_(false),
@@ -245,7 +244,7 @@ ACLChecklist::nonBlockingCheck(ACLCB * callback_, void *callback_data_)
     /** The ACL List should NEVER be NULL when calling this method.
      * Always caller should check for NULL and handle appropriate to its needs first.
      * We cannot select a sensible default for all callers here. */
-    if (accessList == NULL) {
+    if (accessList == nullptr) {
         debugs(28, DBG_CRITICAL, "SECURITY ERROR: ACL " << this << " checked with nothing to match against!!");
         checkCallback(ACCESS_DUNNO);
         return;
@@ -307,8 +306,6 @@ ACLChecklist::matchAndFinish()
 Acl::Answer const &
 ACLChecklist::fastCheck(const Acl::Tree * list)
 {
-    PROF_start(aclCheckFast);
-
     preCheck("fast ACLs");
     asyncCaller_ = false;
 
@@ -325,7 +322,6 @@ ACLChecklist::fastCheck(const Acl::Tree * list)
 
     changeAcl(savedList);
     occupied_ = false;
-    PROF_stop(aclCheckFast);
     return currentAnswer();
 }
 
@@ -335,21 +331,18 @@ ACLChecklist::fastCheck(const Acl::Tree * list)
 Acl::Answer const &
 ACLChecklist::fastCheck()
 {
-    PROF_start(aclCheckFast);
-
     preCheck("fast rules");
     asyncCaller_ = false;
 
     debugs(28, 5, "aclCheckFast: list: " << accessList);
     const Acl::Tree *acl = cbdataReference(accessList);
-    if (acl != NULL && cbdataReferenceValid(acl)) {
+    if (acl != nullptr && cbdataReferenceValid(acl)) {
         matchAndFinish(); // calls markFinished() on success
 
         // if finished (on a match or in exceptional cases), stop
         if (finished()) {
             cbdataReferenceDone(acl);
             occupied_ = false;
-            PROF_stop(aclCheckFast);
             return currentAnswer();
         }
 
@@ -360,7 +353,6 @@ ACLChecklist::fastCheck()
     calcImplicitAnswer();
     cbdataReferenceDone(acl);
     occupied_ = false;
-    PROF_stop(aclCheckFast);
 
     return currentAnswer();
 }
@@ -380,7 +372,7 @@ ACLChecklist::calcImplicitAnswer()
     // else we saw no rules and will respond with ACCESS_DUNNO
 
     implicitRuleAnswer.implicit = true;
-    debugs(28, 3, HERE << this << " NO match found, last action " <<
+    debugs(28, 3, this << " NO match found, last action " <<
            lastAction << " so returning " << implicitRuleAnswer);
     markFinished(implicitRuleAnswer, "implicit rule won");
 }
