@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SRC_BYTECOUNTER_H
-#define SQUID_SRC_BYTECOUNTER_H
+#ifndef SQUID_SRC_BASE_BYTECOUNTER_H
+#define SQUID_SRC_BASE_BYTECOUNTER_H
 
 /// counter for accumulating byte values
 class ByteCounter
@@ -25,5 +25,5 @@ public:
     size_t kb = 0;
 };
 
-#endif /* SQUID_SRC_BYTECOUNTER_H */
+#endif /* SQUID_SRC_BASE_BYTECOUNTER_H */
 
