@@ -6,13 +6,13 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_COMM_COMM_INTERNAL_H
-#define SQUID_COMM_COMM_INTERNAL_H
+#ifndef SQUID_SRC_COMM_COMM_INTERNAL_H
+#define SQUID_SRC_COMM_COMM_INTERNAL_H
 
 /* misc collection of bits shared by Comm code, but not needed by the rest of Squid. */
 
 bool isOpen(const int fd);
 void commStopHalfClosedMonitor(int fd);
 
-#endif
+#endif /* SQUID_SRC_COMM_COMM_INTERNAL_H */
 
