@@ -6,16 +6,15 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_FS_MODULE_H
-#define SQUID_FS_MODULE_H
+#ifndef SQUID_SRC_FS_MODULE_H
+#define SQUID_SRC_FS_MODULE_H
 
 namespace Fs
 {
 
 void Init();
-void Clean();
 
 } // namespace Fs
 
-#endif /* SQUID_FS_MODULE_H */
+#endif /* SQUID_SRC_FS_MODULE_H */
 
