@@ -15,6 +15,7 @@
 #include "comm/Connection.h"
 #include "fde.h"
 #include "ip/Intercept.h"
+#include "ip/tools.h"
 #include "src/tools.h"
 
 #include <cerrno>
@@ -119,15 +120,6 @@ Ip::Intercept::StopTransparency(const char *str)
     }
 }
 
-void
-Ip::Intercept::StopInterception(const char *str)
-{
-    if (interceptActive_) {
-        debugs(89, DBG_IMPORTANT, "Stopping IP interception: " << str);
-        interceptActive_ = 0;
-    }
-}
-
 bool
 Ip::Intercept::NetfilterInterception(const Comm::ConnectionPointer &newConn)
 {
@@ -151,24 +143,38 @@ Ip::Intercept::NetfilterInterception(const Comm::ConnectionPointer &newConn)
         debugs(89, 5, "address NAT: " << newConn);
         return true;
     }
+#else
+    (void)newConn;
 #endif
     return false;
 }
 
-bool
-Ip::Intercept::TproxyTransparent(const Comm::ConnectionPointer &newConn)
+void
+Ip::Intercept::StartTransparency()
 {
+    // --enable-linux-netfilter
+    // --enable-pf-transparent
+    // --enable-ipfw-transparent
 #if (LINUX_NETFILTER && defined(IP_TRANSPARENT)) || \
     (PF_TRANSPARENT && defined(SO_BINDANY)) || \
     (IPFW_TRANSPARENT && defined(IP_BINDANY))
-
-    /* Trust the user configured properly. If not no harm done.
-     * We will simply attempt a bind outgoing on our own IP.
-     */
-    debugs(89, 5, HERE << "address TPROXY: " << newConn);
-    return true;
+    transparentActive_ = 1;
 #else
-    return false;
+    throw TextException("requires TPROXY feature to be enabled by ./configure", Here());
+#endif
+}
+
+void
+Ip::Intercept::StartInterception()
+{
+    // --enable-linux-netfilter
+    // --enable-ipfw-transparent
+    // --enable-ipf-transparent
+    // --enable-pf-transparent
+#if IPF_TRANSPARENT || LINUX_NETFILTER || IPFW_TRANSPARENT || PF_TRANSPARENT
+    interceptActive_ = 1;
+#else
+    throw TextException("requires NAT Interception feature to be enabled by ./configure", Here());
 #endif
 }
 
@@ -180,9 +186,10 @@ Ip::Intercept::IpfwInterception(const Comm::ConnectionPointer &newConn)
      * There is no way to identify whether they came from NAT or not.
      * Trust the user configured properly.
      */
-    debugs(89, 5, HERE << "address NAT: " << newConn);
+    debugs(89, 5, "address NAT: " << newConn);
     return true;
 #else
+    (void)newConn;
     return false;
 #endif
 }
@@ -210,7 +217,7 @@ Ip::Intercept::IpfInterception(const Comm::ConnectionPointer &newConn)
         newConn->local.getInAddr(natLookup.nl_inipaddr.in4);
         newConn->remote.getInAddr(natLookup.nl_outipaddr.in4);
     }
-#else
+#else /* HAVE_STRUCT_NATLOOKUP_NL_INIPADDR_IN6 */
         // warn once every 10 at critical level, then push down a level each repeated event
         static int warningLevel = DBG_CRITICAL;
         debugs(89, warningLevel, "Your IPF (IPFilter) NAT does not support IPv6. Please upgrade it.");
@@ -219,7 +226,7 @@ Ip::Intercept::IpfInterception(const Comm::ConnectionPointer &newConn)
     }
     newConn->local.getInAddr(natLookup.nl_inip);
     newConn->remote.getInAddr(natLookup.nl_outip);
-#endif
+#endif /* HAVE_STRUCT_NATLOOKUP_NL_INIPADDR_IN6 */
     natLookup.nl_inport = htons(newConn->local.port());
     natLookup.nl_outport = htons(newConn->remote.port());
     // ... and the TCP flag
@@ -269,7 +276,7 @@ Ip::Intercept::IpfInterception(const Comm::ConnectionPointer &newConn)
         x = ioctl(natfd, SIOCGNATL, &natLookup);
     }
 
-#endif
+#endif /* defined(IPFILTER_VERSION) ... */
     if (x < 0) {
         const auto xerrno = errno;
         if (xerrno != ESRCH) {
@@ -278,7 +285,7 @@ Ip::Intercept::IpfInterception(const Comm::ConnectionPointer &newConn)
             natfd = -1;
         }
 
-        debugs(89, 9, HERE << "address: " << newConn);
+        debugs(89, 9, "address: " << newConn);
         return false;
     } else {
 #if HAVE_STRUCT_NATLOOKUP_NL_REALIPADDR_IN6
@@ -290,10 +297,12 @@ Ip::Intercept::IpfInterception(const Comm::ConnectionPointer &newConn)
         newConn->local = natLookup.nl_realip;
 #endif
         newConn->local.port(ntohs(natLookup.nl_realport));
-        debugs(89, 5, HERE << "address NAT: " << newConn);
+        debugs(89, 5, "address NAT: " << newConn);
         return true;
     }
 
+#else
+    (void)newConn;
 #endif /* --enable-ipf-transparent */
     return false;
 }
@@ -310,7 +319,7 @@ Ip::Intercept::PfInterception(const Comm::ConnectionPointer &newConn)
      *
      * Trust the user configured properly.
      */
-    debugs(89, 5, HERE << "address NAT divert-to: " << newConn);
+    debugs(89, 5, "address NAT divert-to: " << newConn);
     return true;
 
 #else /* USE_NAT_DEVPF / --with-nat-devpf */
@@ -352,7 +361,7 @@ Ip::Intercept::PfInterception(const Comm::ConnectionPointer &newConn)
             close(pffd);
             pffd = -1;
         }
-        debugs(89, 9, HERE << "address: " << newConn);
+        debugs(89, 9, "address: " << newConn);
         return false;
     } else {
         if (newConn->remote.isIPv6())
@@ -360,47 +369,25 @@ Ip::Intercept::PfInterception(const Comm::ConnectionPointer &newConn)
         else
             newConn->local = nl.rdaddr.v4;
         newConn->local.port(ntohs(nl.rdport));
-        debugs(89, 5, HERE << "address NAT: " << newConn);
+        debugs(89, 5, "address NAT: " << newConn);
         return true;
     }
 #endif /* --with-nat-devpf */
+#else
+    (void)newConn;
 #endif /* --enable-pf-transparent */
     return false;
 }
 
 bool
-Ip::Intercept::Lookup(const Comm::ConnectionPointer &newConn, const Comm::ConnectionPointer &listenConn)
+Ip::Intercept::LookupNat(const Comm::Connection &aConn)
 {
-    /* --enable-linux-netfilter    */
-    /* --enable-ipfw-transparent   */
-    /* --enable-ipf-transparent    */
-    /* --enable-pf-transparent     */
-#if IPF_TRANSPARENT || LINUX_NETFILTER || IPFW_TRANSPARENT || PF_TRANSPARENT
+    debugs(89, 5, "address BEGIN: me/client= " << aConn.local << ", destination/me= " << aConn.remote);
+    assert(interceptActive_);
 
-    debugs(89, 5, HERE << "address BEGIN: me/client= " << newConn->local << ", destination/me= " << newConn->remote);
-
-    newConn->flags |= (listenConn->flags & (COMM_TRANSPARENT|COMM_INTERCEPTION));
-
-    /* NP: try TPROXY first, its much quieter than NAT when non-matching */
-    if (transparentActive_ && listenConn->flags&COMM_TRANSPARENT) {
-        if (TproxyTransparent(newConn)) return true;
-    }
-
-    if (interceptActive_ && listenConn->flags&COMM_INTERCEPTION) {
-        /* NAT methods that use sock-opts to return client address */
-        if (NetfilterInterception(newConn)) return true;
-        if (IpfwInterception(newConn)) return true;
-
-        /* NAT methods that use ioctl to return client address AND destination address */
-        if (PfInterception(newConn)) return true;
-        if (IpfInterception(newConn)) return true;
-    }
-
-#else /* none of the transparent options configured */
-    debugs(89, DBG_IMPORTANT, "WARNING: transparent proxying not supported");
-#endif
-
-    return false;
+    Comm::ConnectionPointer newConn = &aConn;
+    return NetfilterInterception(newConn) || IpfwInterception(newConn) || // use sock-opts to return client address
+           PfInterception(newConn) || IpfInterception(newConn); // use ioctl to return client address AND destination address
 }
 
 bool
@@ -430,6 +417,13 @@ Ip::Intercept::ProbeForTproxy(Ip::Address &test)
 
     debugs(3, 3, "Detect TPROXY support on port " << test);
 
+    if (!Ip::EnableIpv6 && test.isIPv6() && !test.setIPv4()) {
+        debugs(3, DBG_CRITICAL, "Cannot use TPROXY for " << test << " because IPv6 support is disabled");
+        if (doneSuid)
+            leave_suid();
+        return false;
+    }
+
     int tos = 1;
     int tmp_sock = -1;
 
