@@ -97,7 +97,7 @@ getNfmarkCallback(enum nf_conntrack_msg_type, struct nf_conntrack *ct, void *con
 {
     auto *mark = static_cast<nfmark_t *>(connmark);
     *mark = nfct_get_attr_u32(ct, ATTR_MARK);
-    debugs(17, 3, asHex(*mark));
+    debugs(17, 3, "mark=0x" << asHex(*mark));
     return NFCT_CB_CONTINUE;
 }
 
