@@ -8,8 +8,8 @@
 
 /* DEBUG: section 16    Cache Manager API */
 
-#ifndef SQUID_MGR_QUERY_PARAMS_H
-#define SQUID_MGR_QUERY_PARAMS_H
+#ifndef SQUID_SRC_MGR_QUERYPARAMS_H
+#define SQUID_SRC_MGR_QUERYPARAMS_H
 
 #include "ipc/forward.h"
 #include "mgr/QueryParam.h"
@@ -48,5 +48,5 @@ private:
 
 } // namespace Mgr
 
-#endif /* SQUID_MGR_QUERY_PARAMS_H */
+#endif /* SQUID_SRC_MGR_QUERYPARAMS_H */
 
