@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SSL_GADGETS_H
-#define SQUID_SSL_GADGETS_H
+#ifndef SQUID_SRC_SSL_GADGETS_H
+#define SQUID_SRC_SSL_GADGETS_H
 
 #if USE_OPENSSL
 
@@ -293,5 +293,5 @@ const ASN1_BIT_STRING *X509_get_signature(const Security::CertPointer &);
 } // namespace Ssl
 
 #endif // USE_OPENSSL
-#endif // SQUID_SSL_GADGETS_H
+#endif /* SQUID_SRC_SSL_GADGETS_H */
 
